"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const text_ast_1 = require("./utils/text-ast");
const fs_1 = require("fs");
const replace = require("replace");
const path = require("path");
function replacer(allDirectives, config) {
    const jsonResult = {};
    allDirectives.forEach(el => {
        try {
            if (el.isComponent()) {
                // Component
                const moduleName = el.getModule().toSummary().type.reference.name;
                const componentName = el.symbol.name;
                const name = moduleName + '.' + componentName;
                if (!jsonResult[moduleName]) {
                    jsonResult[moduleName] = {};
                }
                jsonResult[moduleName][componentName] = {};
                let texts = [];
                el.getTemplateAst().templateAst.forEach(element => {
                    texts.push(...text_ast_1.getTextAst(element));
                });
                const url = el.getResolvedMetadata().templateUrl || el.symbol.filePath;
                texts.forEach((text, i) => {
                    jsonResult[moduleName][componentName][i] = text;
                    replace({
                        regex: text,
                        replacement: `{{ '${name}.${i}' | translate }}`,
                        paths: [url]
                    });
                });
            }
            else {
                // Directive
            }
        }
        catch (e) {
            // Component
            console.error(e);
            // exception only component
        }
    });
    // saving data
    if (!fs_1.existsSync(config.outPath)) {
        fs_1.mkdirSync(config.outPath, { recursive: true });
    }
    const locales = [config.inLocacte, ...config.outLocacte];
    locales.forEach(locale => {
        const outFile = path.join(config.outPath, `${locale}.json`);
        fs_1.writeFile(outFile, JSON.stringify(jsonResult), 'utf8', () => { });
    });
}
exports.replacer = replacer;
//# sourceMappingURL=ngx-translate.js.map