"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const minimist = require("minimist");
const chalk = require("chalk");
const fs_1 = require("fs");
const ngast_1 = require("ngast");
const resource_1 = require("./utils/resource");
const ngxTranslate = require("./ngx-translate");
const i18nTranslate = require("./i18n");
const error = message => {
    console.error(chalk.default.bgRed.white(message));
};
const info = (message, count1, count2) => {
    console.log(chalk.default.green(message) +
        ` ${count1 ? chalk.default.blue(count1) : ""}` +
        ` ${count2 ? "/ " + chalk.default.yellowBright(count2) : ""}`);
};
function translate() {
    const config = getCliConfig();
    console.log("Parsing...");
    let parseError = null;
    const projectSymbols = new ngast_1.ProjectSymbols(config.projectPath, resource_1.resourceResolver, e => (parseError = e));
    let allDirectives = projectSymbols.getDirectives();
    if (!parseError) {
        allDirectives = allDirectives.filter(el => el.symbol.filePath.indexOf("node_modules") === -1);
        switch (config.format) {
            case 'ngx-translate':
                ngxTranslate.replacer(allDirectives, config);
                break;
            case 'i18n':
                i18nTranslate.replacer(allDirectives, config);
                break;
            default:
                error('format "' + config.format + '" unsoported, Only: ngx-translate, i18n.');
                process.exit(1);
                break;
        }
    }
    else {
        error(parseError);
    }
}
exports.translate = translate;
function validateArgs(args, attrs, error) {
    attrs.forEach(attr => {
        if (!args[attr] || args[attr].trim().length === 0) {
            error(`Connot find --${attr} argument`);
            process.exit(1);
        }
    });
}
function getCliConfig() {
    const args = minimist(process.argv.slice(2));
    validateArgs(args, ['in', 'out', 'outPath', 'format'], error);
    let projectPath = args.p;
    const inLocacte = args.in;
    const format = args.format;
    let outLocacte = args.out.split(",");
    const outPath = args.outPath;
    if (!projectPath) {
        projectPath = "./tsconfig.json";
    }
    if (!fs_1.existsSync(projectPath)) {
        error('Cannot find tsconfig at "' + projectPath + '".');
        process.exit(1);
    }
    return {
        projectPath,
        inLocacte,
        format,
        outLocacte,
        outPath
    };
}
//# sourceMappingURL=translate.js.map